@@ -15,7 +15,7 @@ use Mail::DKIM::Signature;
 package Mail::DKIM::Common;
 use base "Mail::DKIM::MessageParser";
 use Carp;
-our $VERSION = 0.34;
+our $VERSION = 0.38;
 
 sub new
 {
@@ -33,7 +33,7 @@ sub add_header
 		$algorithm->add_header($line);
 	}
 
-	if ($line =~ /^([^:]+)\s*:(.*)/s)
+	if ($line =~ /^([^:]+?)\s*:(.*)/s)
 	{
 		my $field_name = lc $1;
 		my $contents = $2;
