@@ -43,6 +43,19 @@ Mail::DKIM::Verifier - verifies a DKIM-signed message
   # what is the result of the verify?
   my $result = $dkim->result;
 
+  # there might be multiple signatures, what is the result per signature?
+  foreach my $signature ($dkim->signatures)
+  {
+      print "signature identity: " . $signature->identity . "\n";
+      print "verify result: " . $signature->result_detail . "\n";
+  }
+
+  # the alleged author of the email may specify how to handle email
+  foreach my $policy ($dkim->policies)
+  {
+      die "fraudulent message" if ($policy->apply($dkim) eq "reject");
+  }
+
 =cut
 
 =head1 DESCRIPTION
@@ -54,7 +67,7 @@ message has been completely read, the signatures are verified and the
 results of the verification can be accessed.
 
 To use the verifier, first create the verifier object. Then start
-"feeding" it the email message to be verified. When all the headers
+"feeding" it the email message to be verified. When all the _headers_
 have been read, the verifier:
 
  1. checks whether any DomainKeys/DKIM signatures were found
@@ -62,12 +75,21 @@ have been read, the verifier:
  3. sets up the appropriate algorithms and canonicalization objects
  4. canonicalizes the headers and computes the header hash
 
-Then, when the body of the message has been completely fed into the
+Then, when the _body_ of the message has been completely fed into the
 verifier, the body hash is computed and the signatures are verified.
 
+The results of the verification can be checked with L</"result()">
+or L</"signatures()">.
+
+Messages that do not verify may be checked against the alleged sender's
+published signing policy with L</"policies()"> and
+L<Mail::DKIM::Policy/"apply()">.
+
 =head1 CONSTRUCTOR
 
-=head2 new() - construct an object-oriented verifier
+=head2 new()
+
+Constructs an object-oriented verifier.
 
   my $dkim = Mail::DKIM::Verifier->new();
 
@@ -89,7 +111,7 @@ is written to the referenced string or file handle.
 package Mail::DKIM::Verifier;
 use base "Mail::DKIM::Common";
 use Carp;
-our $VERSION = 0.34;
+our $VERSION = 0.38;
 
 sub init
 {
@@ -478,7 +500,9 @@ sub finish_body
 
 =head1 METHODS
 
-=head2 PRINT() - feed part of the message to the verifier
+=head2 PRINT()
+
+Feeds part of the message to the verifier.
 
   $dkim->PRINT("a line of the message\015\012");
   $dkim->PRINT("more of");
@@ -488,31 +512,78 @@ Feeds content of the message being verified into the verifier.
 The API is designed this way so that the entire message does NOT need
 to be read into memory at once.
 
-=head2 CLOSE() - call this when finished feeding in the message
+Please note that although the PRINT() method expects you to use
+SMTP-style line termination characters, you should NOT use the
+SMTP-style dot-stuffing technique described in RFC 2821 section 4.5.2.
+Nor should you use a <CR><LF>.<CR><LF> sequence to terminate the
+message.
+
+=head2 CLOSE()
+
+Call this when finished feeding in the message.
 
   $dkim->CLOSE;
 
 This method finishes the canonicalization process, computes a hash,
 and verifies the signature.
 
-=head2 fetch_author_policy() - retrieves a signing policy from DNS
+=head2 fetch_author_domain_policies()
+
+Retrieves ADSP records from DNS.
+
+  my @policies = $dkim->fetch_author_domain_policies;
+  foreach my $policy (@policies)
+  {
+      my $policy_result = $policy->apply($dkim);
+  }
+
+This method will retrieve all applicable
+"author-domain-signing-practices" published in DNS for this message.
+Author policies are keyed to the email address(es) in the From: header,
+i.e. the claimed author of the message.
+
+This method returns a *list* of policy records, since there is allowed
+to be zero or multiple email addresses in the From: header.
+
+The result of the apply() method is one of: "accept", "reject", "neutral".
+
+See also: L</"policies()">.
+
+=cut
+
+sub fetch_author_domain_policies
+{
+	my $self = shift;
+	use Mail::DKIM::AuthorDomainPolicy;
+
+	return () unless $self->{headers_by_name}->{from};
+	my @list = Mail::Address->parse(
+		$self->{headers_by_name}->{from}
+		);
+	my @authors = map { $_->address } @list;
+
+	# fetch the policies
+	return map {
+		Mail::DKIM::AuthorDomainPolicy->fetch(
+			Protocol => "dns",
+			Author => $_,
+			)
+		} @authors;
+}
+
+=head2 fetch_author_policy()
+
+Retrieves a signing policy from DNS.
 
   my $policy = $dkim->fetch_author_policy;
   my $policy_result = $policy->apply($dkim);
 
-The "author" policy, as I call it, is the DKIM Sender Signing Practices
+This method retrieves the DKIM Sender Signing Practices
 record as described in Internet Draft draft-ietf-dkim-ssp-00-01dc.
-I call it the "author" policy because it is keyed to the email address
-in the From: header, i.e. the author of the message.
+This Internet Draft is now obsolete; this method is only kept for
+backward-compatibility purposes.
 
-The IETF is still actively working on this Internet Draft, so the
-exact mechanisms are subject to change.
-
-If the email being verified has no From header at all
-(which violates email standards),
-then this method will C<die>.
-
-The result of the apply() method is one of: "accept", "reject", "neutral".
+Please use the L</"policies()"> method instead.
 
 =cut
 
@@ -532,27 +603,9 @@ sub fetch_author_policy
 			);
 }
 
-sub fetch_author_domain_policies
-{
-	my $self = shift;
-	use Mail::DKIM::AuthorDomainPolicy;
+=head2 fetch_sender_policy()
 
-	return () unless $self->{headers_by_name}->{from};
-	my @list = Mail::Address->parse(
-		$self->{headers_by_name}->{from}
-		);
-	my @authors = map { $_->address } @list;
-
-	# fetch the policies
-	return map {
-		Mail::DKIM::DkimPolicy->fetch(
-			Protocol => "dns",
-			Author => $_,
-			)
-		} @authors;
-}
-
-=head2 fetch_sender_policy() - retrieves a signing policy from DNS
+Retrieves a signing policy from DNS.
 
   my $policy = $dkim->fetch_sender_policy;
   my $policy_result = $policy->apply($dkim);
@@ -570,6 +623,8 @@ then this method will C<die>.
 
 The result of the apply() method is one of: "accept", "reject", "neutral".
 
+See also: L</"policies()">.
+
 =cut
 
 sub fetch_sender_policy
@@ -589,7 +644,9 @@ sub fetch_sender_policy
 			);
 }
 
-=head2 load() - load the entire message from a file handle
+=head2 load()
+
+Load the entire message from a file handle.
 
   $dkim->load($file_handle);
 
@@ -597,7 +654,9 @@ Reads a complete message from the designated file handle,
 feeding it into the verifier. The message must use <CRLF> line
 terminators (same as the SMTP protocol).
 
-=head2 message_originator() - access the "From" header
+=head2 message_originator()
+
+Access the "From" header.
 
   my $address = $dkim->message_originator;
 
@@ -613,7 +672,9 @@ To get just the email address part, do:
 
 See also L</"message_sender()">.
 
-=head2 message_sender() - access the "From" or "Sender" header
+=head2 message_sender()
+
+Access the "From" or "Sender" header.
 
   my $address = $dkim->message_sender;
 
@@ -632,7 +693,9 @@ transmission of the message. For example, if a secretary were to send a
 message for another person, the "sender" would be the secretary and
 the "originator" would be the actual author.
 
-=head2 policies() - retrieves applicable signing policies from DNS
+=head2 policies()
+
+Retrieves applicable signing policies from DNS.
 
   my @policies = $dkim->policies;
   foreach my $policy (@policies)
@@ -671,7 +734,9 @@ sub policies
 }
 
 
-=head2 result() - access the result of the verification
+=head2 result()
+
+Access the result of the verification.
 
   my $result = $dkim->result;
 
@@ -710,13 +775,15 @@ Returned if no DKIM-Signature headers (valid or invalid) were found.
 
 In case of multiple signatures, the "best" result will be returned.
 Best is defined as "pass", followed by "fail", "invalid", and "none".
-To examine the results of individual signatures, use the L</signatures>
+To examine the results of individual signatures, use the L</"signatures()">
 method to retrieve the signature objects. See
-L<Mail::DKIM::Signature/result>.
+L<Mail::DKIM::Signature/"result()">.
 
 =cut
 
-=head2 result_detail() - access the result, plus details if available
+=head2 result_detail()
+
+Access the result, plus details if available.
 
   my $detail = $dkim->result_detail;
 
@@ -757,7 +824,9 @@ The following are possible results from the result_detail() method:
   invalid (public key: OpenSSL error: ...)
   none
 
-=head2 signature() - access the message's DKIM signature
+=head2 signature()
+
+Access the message's DKIM signature.
 
   my $sig = $dkim->signature;
 
@@ -770,7 +839,9 @@ Best is defined as "pass", followed by "fail", "invalid", and "none".
 
 =cut
 
-=head2 signatures() - access all of this message's signatures
+=head2 signatures()
+
+Access all of this message's signatures.
 
   my @all_signatures = $dkim->signatures;
 
